@@ -279,7 +279,10 @@ class SkillRequest(SkillRequestType):
         return cls(
             user=cls.User(
                 user_id=user.get('user_id'),
-                client=user.get('client'),
+                client=cls.User.Client(
+                    name=user.get('client')['name'],
+                    type=user.get('client')['type']
+                ),
                 global_id=user.get('global_id')
             ),
             update=cls.Update(
